this.name			= "adck_wyvern_explorer";
this.author			= "Montana05";
this.description	= "event handler for the ADCK Wyvern Explorer OXP";
this.version		= "2.00";
this.copyright		= "2022 Montana05";
this.licence   		= "CC BY-NC-SA 4.0";
"use strict";

this.shipSpawned = function(ship)
{
	if(ship.dataKey.search(/adck_wyvern_explorer/i) < 0 || ship.hasRole("cargopod") || ship.isSubEntity || ship.isPlayer)
	{
		return;
	}
	else
	{
		var shipType = ship.dataKey;
		var shipRole = ship.primaryRole;
		var cargoLoad = ship.cargoSpaceUsed;

		// setup escape pods
		if(ship.hasRole("escape-capsule"))
		{
			let crewName = expandDescription("[nom]");
			let crewDescription = "a crew member of an evacuated ship";
			let crewRole = "hunter";  // the role is not particular important anymore, all data will be added by the script
			let crewRace = expandDescription("[adck_wyvern_explorer_races_scientific]");  // add a race to the crew members
			let crewRank = expandDescription("[adck_wyvern_explorer_crew_civil_small]");
			let crewInsurance = this.$getRndInteger(90, 450);
			let crewBounty = 0;
			
			switch(shipType) 
			{
				case "adck_wyvern_explorer_escape_pod_std":

					crewName = ("the " + crewRace + " " + crewRank + " " + expandDescription("[nom]"));
					crewDescription = "a ship crew member";
					crewRole = "hunter";
					crewInsurance = this.$getRndInteger(90, 450);
					break;

				case "adck_wyvern_explorer_escape_pod_std_passenger":

					crewName = ("the " + crewRace + " " + expandDescription("[nom]"));
					crewDescription = "a interstellar passenger";
					crewRole = "passenger";
					crewInsurance = this.$getRndInteger(90, 450);
					break;

				case "adck_wyvern_explorer_escape_pod_std_criminal":

					crewName = ("the " + crewRace + " " + expandDescription("[nom]"));
					crewDescription = "a " + expandDescription("[adck_wyvern_explorer_criminals]") +  "wanted by GalCop police";
					crewRole = "pirate";
					crewBounty = crewInsurance + (15 * system.government);  // stable governments pay extra bonus
					crewInsurance = 0;
					break;

				case "adck_wyvern_explorer_escape_pod_std_pirate":

					crewName = ("the " + crewRace + " " + expandDescription("[adck_wyvern_explorer_pirate_nicknames]") + expandDescription("[nom]"));
					crewDescription = "a " + expandDescription("[adck_wyvern_explorer_criminals]") +  "wanted by GalCop police";
					crewRole = "pirate";
					crewBounty = (crewInsurance * 1.25) + (25 * system.government);  // stable governments pay extra bonus
					crewInsurance = 0;
					break;
					
				case "adck_wyvern_explorer_escape_pod_alliance":

					crewName = ("the " + crewRace + " " + crewRank + " " + expandDescription("[nom]"));
					crewDescription = "a crew member of a ship in the service of the Alliance of Independent Systems";
					crewRole = "hunter";
					crewInsurance = (crewInsurance * 3.00);  // the emissaries of the alliance assist their employees
					break;
					
				case "adck_wyvern_explorer_escape_pod_alliance_criminal":

					crewName = ("the " + crewRace + " " + crewRank + " " + expandDescription("[nom]"));
					crewDescription = "a rogue crew member of a ship in the service of the Alliance of Independent Systems";
					crewRole = "pirate";
					crewBounty = (crewInsurance * 3.00) + (15 * system.government);  // stable governments pay extra bonus
					crewInsurance = 0;
					break;
					
				default: 
	
					break;	
			};

			ship.setCrew
			(
				{
					name: crewName,
					short_description: crewDescription,
					role: crewRole,
					species: crewRace,
					insurance: crewInsurance,
					bounty: crewBounty
				}
			);

			// removes individual roles
			ship.primaryRole = "escape-capsule";
		}
		else
		{
			if(ship.hasRole("GalCop_alien"))
			{
				// adds alien classification
				ship.primaryRole = "alien_trader";
				shipRole = ship.primaryRole;
				ship.scanDescription = "Alien";  // Warning: don't use in shipdata.plist, it will crash the game

				// individual names based on Alliance systems (https://www.edsm.net/en/search/systems/index/)
				const alliance_name_array = 
				[" Ao Guang-", " Shoujeman-", " Keries-", " Arcturus-", " Nzambassee-", " Mullag-", " Morgor-", " Eranin-", " Huokang-", " Al Mina-"];

				let alliance_name = 
				alliance_name_array[Math.floor(Math.random() * alliance_name_array.length)];

				ship.displayName = "Alliance Ship " + ship.name + alliance_name + this.$getRndInteger(100, 999);
			};
			
			switch(shipRole) 
			{
				case "trader":
				case "sunskim-trader":
				case "pirate":
				case "pirate-light-freighter":
				case "adck_wyvern_explorer_I":
				case "adck_wyvern_explorer_IIM":
				case "adck_wyvern_explorer_I_pirate":
				case "adck_wyvern_explorer_IIM_pirate":

					if(shipRole == "adck_wyvern_explorer_I" || shipRole == "adck_wyvern_explorer_IIM")
					{
						ship.primaryRole = "trader";
					};

					if(shipRole == "adck_wyvern_explorer_I_pirate" || shipRole == "adck_wyvern_explorer_IIM_pirate")
					{
						ship.primaryRole = "pirate";
					};
				
					while(ship.cargoSpaceUsed <= 1)  // makes sure that there is some cargo
					{
						if(this.$getRndInteger(1, 6) < 4)
						{
							ship.setCargoType("PLENTIFUL_GOODS");
						}
						else
						{
							ship.setCargoType("SCARCE_GOODS");
						};
					};	
					break;

				case "scavenger":
				case "adck_wyvern_explorer_IIP_02":	

					ship.primaryRole = "scavenger";
				
					if(shipType.search(/_IIP_/i) >= 0)
					{
						ship.forwardWeapon = "EQ_WEAPON_PULSE_LASER";  // Wyvern Explorer II-P exchanges mining to pulse laser
					};

					if(cargoLoad <= 1)
					{
						for(var i = this.$getRndInteger(5, 12) - 1 ; i >= 0 ; --i)
						{
							ship.adjustCargo(this.$adck_wyvern_explorer_scavenger_cargo(), 1);
						};
					};
					break;

				case "miner":
				case "adck_wyvern_explorer_IIP_01":
				
					ship.primaryRole = "miner";

					if(cargoLoad <= 1)
					{
						for(var i = this.$getRndInteger(5, 12) - 1 ; i >= 0 ; --i)
						{
							ship.adjustCargo(this.$adck_wyvern_explorer_miner_cargo(), 1);
						};
					};
					break;

				case "hunter":
				case "hunter-medium":
				case "pirate-medium-fighter":
				case "adck_wyvern_explorer_I_hunter":
				case "adck_wyvern_explorer_IIM_hunter":
							
					if(shipRole == "adck_wyvern_explorer_I_hunter" || shipRole == "adck_wyvern_explorer_IIM_hunter")
					{
						ship.primaryRole = "hunter";
					};
				
					if(cargoLoad <= 1)
					{
						for(var i = this.$getRndInteger(5, 10) - 1 ; i >= 0 ; --i)
						{
							ship.adjustCargo(this.$adck_wyvern_explorer_space_jockey_cargo(), 1);
						};
					};
					break;

				case "alien_trader":

					if(cargoLoad <= 1)
					{
						for(var i = this.$getRndInteger(5, 12) - 1 ; i >= 0 ; --i)
						{
							ship.adjustCargo(this.$adck_wyvern_explorer_alien_cargo(), 1);
						};
					};
					break;	
	
				default: 
	
					break;
			};
		};
		// if there is an existing script in shipDied time to move it
		ship.script.$adck_wyvern_explorer_shipDied_old = ship.script.shipDied;
		ship.script.shipDied = this.$adck_wyvern_explorer_shipDied;	
	};
};	

this.$adck_wyvern_explorer_shipDied = function $adck_wyvern_explorer_shipDied(whom, why) 
{
	if(this.ship.dataKey.search(/adck_wyvern_explorer/i) < 0 || 
	   this.ship.hasRole("escape-capsule") || this.ship.hasRole("cargopod") || this.ship.isSubEntity || this.ship.isPlayer)
	{
		return;
	}
	else
	{
		this.name = "adck_wyvern_explorer";
		let dice = worldScripts.adck_wyvern_explorer;
		let diceRoll = dice.$getRndInteger;
				
		let shipRole = this.ship.primaryRole;
		let shipBounty = this.ship.bounty;
		let shipPos = this.ship.position;
		let MRP01 = 0;
		let criminalCrew = 0;
		let pirateCrew = 0;

		if(worldScripts["MRP01_ressource_spawn"])  // Montanas Ressource Pack 01 OXP
		{
			MRP01 = 1;
		};
		
		if(shipBounty > 7 && shipBounty < 15)
		{
			criminalCrew = 1;
		};

		if(shipBounty > 14 || this.ship.isPirate)
		{
			pirateCrew = 1;
		};

		// if Montanas Ressource Pack 01 OXP is installed the containers from there are used, otherwise let the core-game handle it
		// exception: The Aliiance ship is using individual cargopods and is addressed separately
		if(MRP01 == 1 && this.ship.cargoSpaceUsed > 0 && shipRole != "alien_trader")
		{
			for(let i = this.ship.cargoList.length - 1 ; i >= 0 ; --i)
			{
				let cargoType = this.ship.cargoList[i].commodity;
				let cargoPod = ("MRP01_container_" + cargoType);
				let cargoCount = this.ship.cargoList[i].quantity;
				
				system.addShips(cargoPod, cargoCount, shipPos);
			};
		};

		switch(shipRole) 
		{
			case "trader":
			case "sunskim-trader":

				if(criminalCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_criminal", diceRoll(1, 2), shipPos);
				}
				else if(pirateCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_pirate", diceRoll(1, 2), shipPos);
				}
				else
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_trader", diceRoll(1, 2), shipPos);
				};
			
				if(MRP01 == 1 && diceRoll(1, 10) > 8)
				{
					system.addShips("MRP01_container_cash", diceRoll(1, 2), shipPos);
				};
				break;

			case "scavenger":
			case "miner":
				
				if(criminalCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_criminal", 1, shipPos);
				}
				else if(pirateCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_pirate", 1, shipPos);
				}
				else
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std", 1, shipPos);
				};
				break;
			
			case "hunter":
			case "hunter-medium":

				if(criminalCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_criminal", diceRoll(1, 2), shipPos);
				}
				else if(pirateCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std_pirate", diceRoll(1, 2), shipPos);
				}
				else
				{
					system.addShips("adck_wyvern_explorer_escape_pod_std", diceRoll(1, 2), shipPos);
				};
			
				if(MRP01 == 1 && diceRoll(1, 10) > 8)
				{
					system.addShips("MRP01_container_cash", diceRoll(1, 2), shipPos);
					system.addShips("MRP01_container_prisoners", diceRoll(1, 2), shipPos)
				};
				break;
				
			case "pirate-light-freighter":

				system.addShips("adck_wyvern_explorer_escape_pod_std_pirate", diceRoll(1, 2), shipPos);
				
				if(MRP01 == 1 && diceRoll(1, 10) > 9)
				{
					system.addShips("MRP01_container_cash", diceRoll(1, 2), shipPos);
				};
				break;

			case "pirate":
			case "pirate-medium-fighter":
					
				system.addShips("adck_wyvern_explorer_escape_pod_std_pirate", diceRoll(1, 2), shipPos);
				break;
			
			case "alien_trader":

				if(criminalCrew == 1 || pirateCrew == 1)
				{
					system.addShips("adck_wyvern_explorer_escape_pod_alliance_criminal", 1, shipPos);
				}
				else
				{
					system.addShips("adck_wyvern_explorer_escape_pod_alliance", 1, shipPos);
				};
			
				if(this.ship.cargoSpaceUsed > 0)
				{
					for(let i = this.ship.cargoList.length - 1 ; i >= 0 ; --i)
					{
						let cargoType = this.ship.cargoList[i].commodity;
						let cargoPod = ("adck_wyvern_explorer_alliance_container_" + cargoType);
						let cargoCount = this.ship.cargoList[i].quantity;
						
						system.addShips(cargoPod, cargoCount, shipPos);
					};
				};
				break;	
	
			default:
				
				if(criminalCrew == 1)
    			{
					system.addShips("adck_wyvern_explorer_escape_pod_std_criminal", diceRoll(1, 2), shipPos);
				}
				else if(pirateCrew == 1)
    			{
					system.addShips("adck_wyvern_explorer_escape_pod_std_pirate", diceRoll(1, 2), shipPos);
				}
				else
    			{
					system.addShips("adck_wyvern_explorer_escape_pod_std", diceRoll(1, 2), shipPos);
				};
				break;	
		};
	};

	if(this.ship.script.$adck_wyvern_explorer_shipDied_old)
	{
		this.ship.script.$adck_wyvern_explorer_shipDied_old(whom, why);
	};
};

this.$adck_wyvern_explorer_scavenger_cargo = function()
{
	const scavenger_cargo_array = ["alloys", "gold", "platinum", "computers", "machinery", "slaves"];

	// Montanas Ressource Pack 01 OXP
	if(worldScripts["MRP01_ressource_spawn"] && scavenger_cargo_array.indexOf("quirium_crystal") < 0)
	{
		scavenger_cargo_array.push("quirium_crystal");
	};
	
	let scavenger_cargo = 
	scavenger_cargo_array[Math.floor(Math.random() * scavenger_cargo_array.length)];
		
	return (scavenger_cargo);
};

this.$adck_wyvern_explorer_miner_cargo = function()
{
	const miner_cargo_array = ["radioactives", "minerals", "gold", "platinum", "gem_stones"];
	
	let miner_cargo = 
	miner_cargo_array[Math.floor(Math.random() * miner_cargo_array.length)];
		
	return (miner_cargo);
};

// food, medicine, booze and guns, what else you need for your trip ? :P
this.$adck_wyvern_explorer_space_jockey_cargo = function()
{
	const space_jockey_cargo_array = ["firearms", "food", "liquor_wines"];

	 // Darkside Moonshine Distillery OXP
	if(worldScripts["witchfire-populator"] && space_jockey_cargo_array.indexOf("witchfire_whiskey") < 0)
	{
		space_jockey_cargo_array.push("witchfire_whiskey");
	};
	
	// medicine is part of several OXP's therefore a check of the market is required
	if(system.mainStation)
	{
		let goods = system.mainStation.market;
		for(let i in goods) 
		{
			if(goods[i].key == ["medicine"] && space_jockey_cargo_array.indexOf("medicine") < 0)
			{
				space_jockey_cargo_array.push("medicine");
			};
		};
	}; 

	let space_jockey_cargo = 
	space_jockey_cargo_array[Math.floor(Math.random() * space_jockey_cargo_array.length)];

	return (space_jockey_cargo);
};

this.$adck_wyvern_explorer_alien_cargo = function()
{
	const alien_cargo_array = ["machinery", "computers", "alien_items"];
	
	let alien_cargo = 
	alien_cargo_array[Math.floor(Math.random() * alien_cargo_array.length)];
		
	return (alien_cargo);
};

this.$getRndInteger = function(min, max)
{
	return (Math.floor(Math.random() * (max - min + 1) ) + min);
};
